@@ -68,9 +68,10 @@ BASE = __get_source_path__(SOURCE_PATH)
 OS = __get_operating_system__()
 #__check_alias__(alias=ALIAS, executable=f"{SOURCE_PATH}/")
 
-# version.
-try: version = Files.load(f"{SOURCE_PATH}/.version.py")
-except: version = "unkown"
+# options.
+ERROR_TRACEBACK = os.environ.get("R3SPONSE_ERROR_TRACEBACK")
+if str(ERROR_TRACEBACK) in ["True", "true", True]: ERROR_TRACEBACK = True
+else: ERROR_TRACEBACK = False
 
 # universal variables.
 USER = OWNER = os.environ.get("USER")
@@ -78,8 +79,9 @@ GROUP = "root"
 HOME_BASE = "/home/"
 HOME = f"/home/{os.environ.get('USER')}/"
 MEDIA = f"/media/{os.environ.get('USER')}/"
-if OS in ["macos"]: 
+if OS in ["macos"]: 	
 	HOME_BASE = "/Users/"
 	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
 	GROUP = "wheel"
+
